@@ -12,7 +12,7 @@ class logger:
         logger = logging.getLogger(__name__)
         logger.setLevel(logging.DEBUG)
 
-        log_file = logging.FileHandler(filename, mode='w', encoding='utf-8')
+        log_file = logging.FileHandler(filename, encoding='utf-8')
         log_format = logging.Formatter(fmt='%(levelname)s - %(asctime)s.%(msecs)03d - Line %(lineno)s: %(message)s', datefmt='%H:%M:%S')
         log_file.setFormatter(log_format)
         logger.addHandler(log_file)
